//<?php

/* To prevent PHP errors (extending class does not exist) revealing path */
if( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	exit;
}

class profilesongs_hook_MemberHook extends _HOOK_CLASS_
{
	public function hasProfileSong()
	{
		try
		{
			try
			{
				return \IPS\Db::i()->select( '*', 'profilesongs_files', array( 'member_id=?', $this->member_id ) )->first();
			}
			catch( \Exception $ex )
			{
				return FALSE;
			}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}

	public function profileSongs()
	{
		try
		{
			try
			{
				$track = array();
				foreach( \IPS\Db::i()->select( '*', 'profilesongs_files', array( 'member_id=?', $this->member_id ), 'position ASC' ) as $tracks )
				{
					$track[] = \IPS\profilesongs\ProfileSongs::load( $tracks['id'] );
				}
	
				return $track;
			}
			catch( \Exception $ex )
			{
				return array();
			}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}

	public function profileSongsCanUse()
	{
		try
		{
			try
			{
				if( \IPS\profilesongs\ProfileSongs\GroupSettings::load( $this->member_group_id, 'group_id' )->can_use )
				{
					return TRUE;
				}
			}
			catch( \OutOfRangeException $e )
			{
				return FALSE;
			}
	
			if( \IPS\Settings::i()->profilesongs_sg AND $this->mgroup_others )
			{
				foreach( \IPS\Member\Group::groups() as $group )
				{
					if( \in_array( $group->g_id, explode( ',', $this->mgroup_others ) ) AND \IPS\profilesongs\ProfileSongs\GroupSettings::load( $group->g_id, 'group_id' )->can_use )
					{
						return TRUE;
					}
				}
			}
	
			return FALSE;
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}

	public function profileSongsUploadSizeLimit()
	{
		try
		{
			try
			{
				return \IPS\profilesongs\ProfileSongs\GroupSettings::load( $this->member_group_id, 'group_id' )->upload_limit;
			}
			catch( \Exception $e )
			{
				return NULL;
			}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}

	public function profileSongsMultipleUploads()
	{
		try
		{
			try
			{
				return \IPS\profilesongs\ProfileSongs\GroupSettings::load( $this->member_group_id, 'group_id' )->multiple_uploads;
			}
			catch( \Exception $e )
			{
				return NULL;
			}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}

	public function profileSongsMaximumFiles()
	{
		try
		{
			try
			{
				return \IPS\profilesongs\ProfileSongs\GroupSettings::load( $this->member_group_id, 'group_id' )->maximum_files;
			}
			catch( \Exception $e )
			{
				return NULL;
			}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}

	public function profileSongsGotTrack( $location=NULL )
	{
		try
		{
			$loggedIn = \IPS\Member::loggedIn();
	
			try
			{
				return \IPS\Db::i()->select( '*', 'profilesongs_files', array( 'member_id=? AND location=?', $loggedIn->member_id, $location ) )->first();
			}
			catch( \Exception $e )
			{
				return NULL;
			}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
}